<?php

namespace Drupal\bing_indexing_api\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\State\StateInterface;
use Drupal\file\FileUsage\FileUsageInterface;

/**
 * Class SettingsForm.
 */
class BingSettingsForm extends FormBase {

  /**
   * Drupal\Core\State\StateInterface definition.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Drupal\file\FileUsage\FileUsageInterface definition.
   *
   * @var \Drupal\file\FileUsage\FileUsageInterface
   */
  protected $fileUsage;

  /**
   * Constructs a new SettingsForm object.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The State Service.
   * @param \Drupal\file\FileUsage\FileUsageInterface $file_usage
   *   The file usage service.
   */
  public function __construct(StateInterface $state, FileUsageInterface $file_usage) {
    $this->state = $state;
    $this->fileUsage = $file_usage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state'),
      $container->get('file.usage')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bing_index_api_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['info'] = [
      '#type' => 'item',
      '#title' => $this->t('Follow <a href="@url" target="_blank">these instructions</a> to setup and obtain your api key', [
        '@url' => "https://www.deworldinsights.com/bing-indexing-api/",
      ]),
    ];

    $form['top'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    ];

    $form['top']['bing_index_api_base_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('The Base Domain of the site'),
      '#description' => $this->t('We are setting this here since sometimes the base domain could be different on the backend.'),
      '#default_value' => $this->state->get('bing_index_api_base_domain'),
      '#required' => TRUE,
    ];

    $form['top']['bing_index_api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Api key'),
      '#default_value' => $this->state->get('bing_index_api_key'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Grab the values.
    $apiKey = $form_state->getValue('bing_index_api_key');
    $domain = $form_state->getValue('bing_index_api_base_domain');

    // Save to use else where.
    $this->state->set('bing_index_api_key', $apiKey);
    $this->state->set('bing_index_api_base_domain', $domain);
  }

}
